==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/java/adapter/jdbc/src/main/java/org/apache/arrow/adapter/jdbc/binder/FixedSizeBinaryBinder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.arrow.adapter.jdbc.binder;

import java.sql.PreparedStatement;
import java.sql.SQLException;

import org.apache.arrow.vector.FixedSizeBinaryVector;

/**
 * A binder for fixed-width binary types.
 */
public class FixedSizeBinaryBinder extends BaseColumnBinder<FixedSizeBinaryVector> {
  /**
   * Create a binder for the given vector using the given JDBC type for null values.
   *
   * @param vector   The vector to draw values from.
   * @param jdbcType The JDBC type code.
   */
  public FixedSizeBinaryBinder(FixedSizeBinaryVector vector, int jdbcType) {
    super(vector, jdbcType);
  }

  @Override
  public void bind(PreparedStatement statement, int parameterIndex, int rowIndex) throws SQLException {
    byte[] binaryData = new byte[vector.getByteWidth()];
    vector.getDataBuffer().getBytes((long) rowIndex * binaryData.length, binaryData, 0, binaryData.length);
    statement.setBytes(parameterIndex, binaryData);
  }
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/java/adapter/jdbc/src/main/java/org/apache/arrow/adapter/jdbc/binder/FixedSizeBinaryBinder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.arrow.adapter.jdbc.binder;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import org.apache.arrow.vector.FixedSizeBinaryVector;

/** A binder for fixed-width binary types. */
public class FixedSizeBinaryBinder extends BaseColumnBinder<FixedSizeBinaryVector> {
  /**
   * Create a binder for the given vector using the given JDBC type for null values.
   *
   * @param vector The vector to draw values from.
   * @param jdbcType The JDBC type code.
   */
  public FixedSizeBinaryBinder(FixedSizeBinaryVector vector, int jdbcType) {
    super(vector, jdbcType);
  }

  @Override
  public void bind(PreparedStatement statement, int parameterIndex, int rowIndex)
      throws SQLException {
    byte[] binaryData = new byte[vector.getByteWidth()];
    vector
        .getDataBuffer()
        .getBytes((long) rowIndex * binaryData.length, binaryData, 0, binaryData.length);
    statement.setBytes(parameterIndex, binaryData);
  }
}
